button - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- Button
- Switch

# Button

Button([value]) -> Button widget

A widget resembling a button.

### Arguments

value
  The text or widget to be displayed on the button.

# Switch

Switch([value, [labels, [options]]]) -> Switch widget

This is very similar to a button. When clicked, it will cycle through it's list of options. The label displayed will be the the item in the labels list at the same index as the current option (value) in the options list. The labels and options need to be exactly the same size.

### Arguments

value
  Must be an item in the options list.
labels
  A list of strings that will be used as labels.
options
  A list of items that are cycled through to determin this widgets value.